ThreadPool

Struct ThreadPool 

pub struct ThreadPool {
    pub threads: Vec<UnsafeCell<*mut Searcher>>,
    pub main_cond: Arc<LockLatch>,
    pub thread_cond: Arc<LockLatch>,
    pub stop: AtomicBool,
    /* private fields */
}
The thread-pool for the chess engine.

Fields

threads: Vec<UnsafeCell<*mut Searcher>>

Access to each thread’s Structure

main_cond: Arc<LockLatch>

Condition for the main thread to start.

thread_cond: Arc<LockLatch>

Condition for all non-main threads

stop: AtomicBool

Stop condition, if true the threads should halt.

Implementations

Source

impl ThreadPool

pub fn new() -> Self

Creates a new ThreadPool

pub fn size(&self) -> usize

Returns the number of threads

pub fn stdout(&mut self, use_stdout: bool)

Sets the use of standard out. This can be changed mid search as well.

pub fn set_thread_count(&mut self, num: usize)

Sets the thread count of the pool. If num is less than 1, nothing will happen.

Safety

Completely unsafe to use when the pool is searching.

pub fn kill_all(&mut self)

Kills and de-allocates all the threads that are running. This function will also block on waiting for the search to finish.

pub fn set_stop(&mut self, stop: bool)

Sets the threads to stop (or not!).

pub fn wait_for_finish(&self)

Waits for all the threads to finish

pub fn wait_for_start(&self)

Waits for all the threads to start.

pub fn wait_for_non_main(&self)

Waits for all non-main threads to finish.

pub fn wait_for_main_start(&self)

Waits for all the non-main threads to start running

pub fn clear_all(&mut self)

Starts a UCI search. The result will be printed to stdout if the stdout setting is true.

pub fn search(&mut self, board: &Board, limits: &Limits) -> BitMove

Performs a standard search, and blocks waiting for a returned BitMove.

pub fn best_move(&mut self) -> BitMove

Returns the best move of a search

pub fn nodes(&self) -> u64

Returns total number of nodes searched so far.